Learn R Programming

simecol (version 0.3-11)

seedfill: Color fill algorithm

Description

Fills a bounded area within a numeric matrix with a given number (color).

Usage

seedfill(z, x=1, y=1, fcol=0, bcol=1, tol=1e-6)

Arguments

z
a matrix containing an image
x, y
start coordinates of the filled area
fcol
numeric value of the fill color
bcol
numeric value of the border value
tol
numeric value of border color tolerance

Value

  • A matrix with the same structure as z.

Details

The function implements a basic color fill algorithm for use in image manipulation or cellular automata.

See Also

neighbours

Examples

Run this code
# define a matrix
z<-matrix(0, nrow=20, ncol=20)

# draw some lines
z[10,]<-z[,10] <- 1
z[5,] <-z[,5]  <- 3

# plot matrix and filled variants
par(mfrow=c(2, 2))
image(z)
image(seedfill(z))
image(seedfill(z ,x=15, y=15, fcol=1, bcol=3))
image(seedfill(z, x=7, y=7, fcol=3, bcol=1))

Run the code above in your browser using DataLab